/* eslint-disable react/jsx-props-no-spreading */
import React, { FC, useState } from 'react';
import {
  Dialog,
  DialogActions,
  DialogContent,
  DialogContentText,
  DialogTitle,
  Button,
  Typography,
} from '@material-ui/core';
import { DriverShiftType } from 'types/DriverShiftType';
import { SubmitHandler, useForm } from 'react-hook-form';
import { getRoleObject } from 'api/getRoleObject';
import { ControlledDateTimePicker } from 'components/Utils/ControlledDateTimePicker';
import { driverShiftStyle } from './DriverShiftPage.style';

type DriverShiftDialogProps = {
  handleClose: () => void;
  isOpen: boolean;
};

export const DriverShiftDialog: FC<DriverShiftDialogProps> = ({
  handleClose,
  isOpen,
}: DriverShiftDialogProps) => {
  const classes = driverShiftStyle();
  const { control, handleSubmit } = useForm<DriverShiftType>({
    mode: 'onSubmit',
  });

  const onSubmit: SubmitHandler<DriverShiftType> = (
    driverShift: DriverShiftType,
  ) => {
    const filledShift = driverShift;
    getRoleObject().then((role) => {
      filledShift.driver = role.id;
      console.log(filledShift);
    });
    handleClose();
  };

  return (
    <div data-testid="DriverShiftDialog">
      <Dialog
        open={isOpen}
        onClose={handleClose}
        aria-labelledby="form-dialog-title"
      >
        <form onSubmit={handleSubmit(onSubmit)} data-testid="Form">
          <DialogTitle id="form-dialog-title">
            <Typography variant="h4" component="h1">
              Book New DriverShift
            </Typography>
          </DialogTitle>
          <DialogContent>
            <DialogContentText>
              Write here below the details of your next DriverShift
            </DialogContentText>
            <Typography
              variant="h5"
              component="h2"
              className={`${classes.paddingBottomKlein} ${classes.paddingTopKlein}`}
            >
              Search
            </Typography>

            <ControlledDateTimePicker
              control={control}
              name="startTime"
              id="start-time"
              label="Start time"
            />

            <ControlledDateTimePicker
              control={control}
              name="endTime"
              id="end-time"
              label="End time"
            />

            <Typography
              variant="h5"
              component="h2"
              className={`${classes.paddingBottomKlein} ${classes.paddingTopKlein}`}
            >
              Trip stage
            </Typography>
          </DialogContent>
          <DialogActions>
            <Button onClick={handleClose} color="primary">
              Cancel
            </Button>
            <Button type="submit" variant="contained" color="primary">
              Insert
            </Button>
          </DialogActions>
        </form>
      </Dialog>
    </div>
  );
};
